#!/usr/bin/python
import RPi.GPIO as GPIO
import time, subprocess, smbus

LCD_RS = 25
LCD_E  = 24
LCD_D4 = 23
LCD_D5 = 17
LCD_D6 = 27
LCD_D7 = 22

GPIO.setmode(GPIO.BCM)
GPIO.setup(LCD_E,  GPIO.OUT)
GPIO.setup(LCD_RS, GPIO.OUT)
GPIO.setup(LCD_D4, GPIO.OUT)
GPIO.setup(LCD_D5, GPIO.OUT)
GPIO.setup(LCD_D6, GPIO.OUT)
GPIO.setup(LCD_D7, GPIO.OUT)

LCD_WIDTH = 16
LCD_LINE_1 = 0x80
LCD_LINE_2 = 0xC0
LCD_CHR = True
LCD_CMD = False
E_PULSE = 0.00005
E_DELAY = 0.00005
pause = 2

def lcd_enable():
  time.sleep(E_DELAY)
  GPIO.output(LCD_E, True)
  time.sleep(E_PULSE)
  GPIO.output(LCD_E, False)
  time.sleep(E_DELAY)

def lcd_byte(bits, mode):
  GPIO.output(LCD_RS, mode)
  GPIO.output(LCD_D4, bits&0x10==0x10)
  GPIO.output(LCD_D5, bits&0x20==0x20)
  GPIO.output(LCD_D6, bits&0x40==0x40)
  GPIO.output(LCD_D7, bits&0x80==0x80)
  lcd_enable()
  GPIO.output(LCD_D4, bits&0x01==0x01)
  GPIO.output(LCD_D5, bits&0x02==0x02)
  GPIO.output(LCD_D6, bits&0x04==0x04)
  GPIO.output(LCD_D7, bits&0x08==0x08)
  lcd_enable()

def lcd_string(message):
  message = message.ljust(LCD_WIDTH," ")
  for i in range(LCD_WIDTH):
    lcd_byte(ord(message[i]),LCD_CHR)

def lcd_anzeige(z1, z2):
    lcd_byte(LCD_LINE_1, LCD_CMD)
    lcd_string(z1)
    lcd_byte(LCD_LINE_2, LCD_CMD)
    lcd_string(z2)

LCD_INIT = [0x33, 0x32, 0x28, 0x0C, 0x06, 0x01]
for i in LCD_INIT:
  lcd_byte(i,LCD_CMD)

DEVICE = 0x20 
IODIRA = 0x00 
IODIRB = 0x01 
GPIOA  = 0x12 
GPIOB  = 0x13 
 
bus = smbus.SMBus(1) 
bus.write_byte_data(DEVICE,IODIRA,0x00)
bus.write_byte_data(DEVICE,IODIRB,0x00)
bus.write_byte_data(DEVICE,GPIOA,0x00)
bus.write_byte_data(DEVICE,GPIOB,0x00)

m1 = 60

try:
  while True:
    zeit = time.localtime()
    m = zeit.tm_min
    h = zeit.tm_hour
    if h > 12:
      h = h - 12
    if m1 <> m:
      bus.write_byte_data(DEVICE,GPIOB,h)
      bus.write_byte_data(DEVICE,GPIOA,m)
      m1 = m
    zeile1 = time.asctime()
    zeile2 = "IP:" + subprocess.check_output(["hostname","-I"])[:-2]
    lcd_anzeige(zeile1, zeile2)
    time.sleep(pause)

except KeyboardInterrupt:
  GPIO.cleanup()
