#!/usr/bin/python
import RPi.GPIO as GPIO
import time, subprocess, os

LCD_RS = 7
LCD_E  = 8
LCD_D4 = 25
LCD_D5 = 24
LCD_D6 = 23
LCD_D7 = 18
T1 = 4
T2 = 17

GPIO.setmode(GPIO.BCM)
GPIO.setup(LCD_E,  GPIO.OUT)
GPIO.setup(LCD_RS, GPIO.OUT)
GPIO.setup(LCD_D4, GPIO.OUT)
GPIO.setup(LCD_D5, GPIO.OUT)
GPIO.setup(LCD_D6, GPIO.OUT)
GPIO.setup(LCD_D7, GPIO.OUT)
GPIO.setup(T1, GPIO.IN, pull_up_down = GPIO.PUD_DOWN)
GPIO.setup(T2, GPIO.IN, pull_up_down = GPIO.PUD_DOWN)

LCD_WIDTH = 16
LCD_LINE_1 = 0x80
LCD_LINE_2 = 0xC0
LCD_CHR = True
LCD_CMD = False
E_PULSE = 0.00005
E_DELAY = 0.00005
INIT  = 0.01
pause = 0.1

def lcd_enable():
  time.sleep(E_DELAY)
  GPIO.output(LCD_E, True)
  time.sleep(E_PULSE)
  GPIO.output(LCD_E, False)
  time.sleep(E_DELAY)

def lcd_byte(bits, mode):
  GPIO.output(LCD_RS, mode)
  GPIO.output(LCD_D4, bits&0x10==0x10)
  GPIO.output(LCD_D5, bits&0x20==0x20)
  GPIO.output(LCD_D6, bits&0x40==0x40)
  GPIO.output(LCD_D7, bits&0x80==0x80)
  lcd_enable()
  GPIO.output(LCD_D4, bits&0x01==0x01)
  GPIO.output(LCD_D5, bits&0x02==0x02)
  GPIO.output(LCD_D6, bits&0x04==0x04)
  GPIO.output(LCD_D7, bits&0x08==0x08)
  lcd_enable()

def lcd_string(message):
  message = message.ljust(LCD_WIDTH," ")
  for i in range(LCD_WIDTH):
    lcd_byte(ord(message[i]),LCD_CHR)

LCD_INIT = [0x33, 0x32, 0x28, 0x0C, 0x06, 0x01]
for i in LCD_INIT:
  lcd_byte(i,LCD_CMD)
  time.sleep(INIT)

n = 0
z = ["", "", "", "", "", ""]

try:
  while True:
    sd1 = os.statvfs('/')
    hd1 = os.statvfs('/media/usb1')
    hd2 = os.statvfs('/media/usb2')
    hd3 = os.statvfs('/media/usb3')
    sd1x = sd1.f_bsize * sd1.f_bavail / 1048576
    hd1x = hd1.f_bsize * hd1.f_bavail / 1048576
    hd2x = hd2.f_bsize * hd2.f_bavail / 1048576
    hd3x = hd3.f_bsize * hd3.f_bavail / 1048576
    z[0] = time.asctime()
    z[1] = "IP:" + subprocess.check_output(["hostname","-I"])[:-2]
    z[2] = "SD  :" + str(sd1x) + " MB"
    z[3] = "USB1:" + str(hd1x) + " MB"
    z[4] = "USB2:" + str(hd2x) + " MB"
    z[5] = "USB3:" + str(hd3x) + " MB"
    if GPIO.input(T1)==1:
      n += 1
      if n > 4:
        n = 4
    if GPIO.input(T2)==1:
      n -= 1
      if n < 0:
        n = 0
    lcd_byte(LCD_LINE_1, LCD_CMD)
    lcd_string(z[n])
    lcd_byte(LCD_LINE_2, LCD_CMD)
    lcd_string(z[n + 1])
    time.sleep(pause)
except KeyboardInterrupt:
  GPIO.cleanup()
