#!/usr/bin/python
import RPi.GPIO as GPIO
import time, subprocess, os

HD_1 = "/media/usb1"
HD_2 = "/media/usb2"
HD_3 = "/media/usb3"

LCD_RS = 25
LCD_E  = 24
LCD_D4 = 23
LCD_D5 = 17
LCD_D6 = 27
LCD_D7 = 22
T1 = 14
T2 = 15

GPIO.setmode(GPIO.BCM)
GPIO.setup(LCD_E,  GPIO.OUT)
GPIO.setup(LCD_RS, GPIO.OUT)
GPIO.setup(LCD_D4, GPIO.OUT)
GPIO.setup(LCD_D5, GPIO.OUT)
GPIO.setup(LCD_D6, GPIO.OUT)
GPIO.setup(LCD_D7, GPIO.OUT)
GPIO.setup(T1, GPIO.IN)
GPIO.setup(T2, GPIO.IN)

LCD_WIDTH = 16
LCD_LINE_1 = 0x80
LCD_LINE_2 = 0xC0
LCD_CHR = True
LCD_CMD = False
E_PULSE = 0.00005
E_DELAY = 0.00005
pause = 0.1

def lcd_enable():
  time.sleep(E_DELAY)
  GPIO.output(LCD_E, True)
  time.sleep(E_PULSE)
  GPIO.output(LCD_E, False)
  time.sleep(E_DELAY)

def lcd_byte(bits, mode):
  GPIO.output(LCD_RS, mode)
  GPIO.output(LCD_D4, bits&0x10==0x10)
  GPIO.output(LCD_D5, bits&0x20==0x20)
  GPIO.output(LCD_D6, bits&0x40==0x40)
  GPIO.output(LCD_D7, bits&0x80==0x80)
  lcd_enable()
  GPIO.output(LCD_D4, bits&0x01==0x01)
  GPIO.output(LCD_D5, bits&0x02==0x02)
  GPIO.output(LCD_D6, bits&0x04==0x04)
  GPIO.output(LCD_D7, bits&0x08==0x08)
  lcd_enable()

def lcd_string(message):
  message = message.ljust(LCD_WIDTH," ")
  for i in range(LCD_WIDTH):
    lcd_byte(ord(message[i]),LCD_CHR)

def lcd_anzeige(z1, z2):
    lcd_byte(LCD_LINE_1, LCD_CMD)
    lcd_string(z1)
    lcd_byte(LCD_LINE_2, LCD_CMD)
    lcd_string(z2)

LCD_INIT = [0x33, 0x32, 0x28, 0x0C, 0x06, 0x01]
for i in LCD_INIT:
  lcd_byte(i,LCD_CMD)

z1 = 0
zeile = ["", "", "", "", "", ""]

try:
  while True:
    s = os.statvfs('/')
    hd1 = os.statvfs(HD_1)
    hd2 = os.statvfs(HD_2)
    hd3 = os.statvfs(HD_3)
    zeile[0] = time.asctime()
    zeile[1] = "IP:" + subprocess.check_output(["hostname","-I"])[:-2]
    zeile[2] = "SD:" + str(s.f_bsize * s.f_bavail / 1048576) + " MB "
    zeile[3] = "USB1:" + str(hd1.f_bsize * hd1.f_bavail / 1048576) + " MB "
    zeile[4] = "USB2:" + str(hd2.f_bsize * hd2.f_bavail / 1048576) + " MB "
    zeile[5] = "USB3:" + str(hd3.f_bsize * hd3.f_bavail / 1048576) + " MB "
    if GPIO.input(T1)==1:
      z1 += 1
      if z1 > 4:
        z1 = 4
    if GPIO.input(T2)==1:
      z1 -= 1
      if z1 < 0:
        z1 = 0
    lcd_anzeige(zeile[z1], zeile[z1 + 1])
    time.sleep(pause)

except KeyboardInterrupt:
  GPIO.cleanup()
